==> pygls-0.11.2.tar.gz: pygls-0.11.2/Implementations.md <==
# Implementations Based on _pygls_

| Name                     | Maintainer                                                            | Repository (optional)                                                      | Notes                                                                                                                         |
|--------------------------|-----------------------------------------------------------------------|----------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------|
| _Anakin Language Server_ | [Andrii Kolomoiets](https://github.com/muffinmad) | [anakin-language-server](https://github.com/muffinmad/anakin-language-server) | Yet another Jedi Python language server |
| _Cmake Language Server_  | [Regen100](https://github.com/regen100)                               | [cmake-language-server](https://github.com/regen100/cmake-language-server) | CMake LSP Implementation
| _Codify Language Server_ | [Open Law Library](http://www.openlawlib.org/)                        | &nbsp;                                                                     | Used in our VS Code extension, _[Codify](https://marketplace.visualstudio.com/items?itemName=openlawlibrary.open-law-codify)_ |
| _Hy Language Server_     | [Rintaro Okamura](https://github.com/rinx) | [hy-language-server](https://github.com/rinx/hy-language-server) | Hy language server wrapping [Jedhy](https://github.com/ekaschalk/jedhy) |
| _Jedi Language Server_   | [Samuel Roeca](https://softwarejourneyman.com/pages/about.html#about) | [jedi-language-server](https://github.com/pappasam/jedi-language-server)   | Python language server wrapping [Jedi](https://github.com/davidhalter/jedi)                                                   |
| _zc.buildout Language Server_   | [Jérome Perrin](https://github.com/perrinjerome) | [zc.buildout.languageserver](https://github.com/perrinjerome/vscode-zc-buildout)   | Language server for [zc.buildout](http://docs.buildout.org/en/latest/) profiles.  |

## _(alphabetic by name, maintainer)_

==> pygls-0.12.1.tar.gz: pygls-0.12.1/Implementations.md <==
# Implementations Based on _pygls_

| Name                     | Maintainer                                                            | Repository (optional)                                                      | Notes                                                                                                                         |
|--------------------------|-----------------------------------------------------------------------|----------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------|
| _Anakin Language Server_ | [Andrii Kolomoiets](https://github.com/muffinmad) | [anakin-language-server](https://github.com/muffinmad/anakin-language-server) | Yet another Jedi Python language server |
| _Cmake Language Server_  | [Regen100](https://github.com/regen100)                               | [cmake-language-server](https://github.com/regen100/cmake-language-server) | CMake LSP Implementation
| _Codify Language Server_ | [Open Law Library](http://www.openlawlib.org/)                        | &nbsp;                                                                     | Used in our VS Code extension, _[Codify](https://marketplace.visualstudio.com/items?itemName=openlawlibrary.open-law-codify)_ |
| _Esbonio Language Server_| [Alex Carney](https://github.com/alcarney) | [esbonio](https://github.com/swyddfa/esbonio) | Language server for [Sphinx](https://www.sphinx-doc.org/en/master/) documentation projects |
| _Hy Language Server_     | [Rintaro Okamura](https://github.com/rinx) | [hy-language-server](https://github.com/rinx/hy-language-server) | Hy language server wrapping [Jedhy](https://github.com/ekaschalk/jedhy) |
| _Jedi Language Server_   | [Samuel Roeca](https://softwarejourneyman.com/pages/about.html#about) | [jedi-language-server](https://github.com/pappasam/jedi-language-server)   | Python language server wrapping [Jedi](https://github.com/davidhalter/jedi)                                                   |
| _Stata Language Server_   | [Hai Bo](https://github.com/HankBO) | [stata-language-server](https://github.com/HankBO/stata-language-server)   | Language server for [Stata](https://www.stata.com/)  |
| _zc.buildout Language Server_   | [Jérome Perrin](https://github.com/perrinjerome) | [zc.buildout.languageserver](https://github.com/perrinjerome/vscode-zc-buildout)   | Language server for [zc.buildout](http://docs.buildout.org/en/latest/) profiles.  |

## _(alphabetic by name, maintainer)_
